@@ -1,6 +1,5 @@
 import sys
 import time
-import warnings
 
 import uuid
 import six
@@ -620,9 +619,6 @@ class Request(object):
 
         return response
 
-    # Uncomment for stage debugging
-    # stage = property(lambda self: self._stage, lambda self, v: print(v))
-
     def respond(self, path_info):
         """Generate a response for the resource at self.path_info. (Core)"""
         try:
@@ -770,28 +766,6 @@ class Request(object):
             inst.set_response()
             cherrypy.serving.response.finalize()
 
-    # ------------------------- Properties ------------------------- #
-
-    def _get_body_params(self):
-        warnings.warn(
-            'body_params is deprecated in CherryPy 3.2, will be removed in '
-            'CherryPy 3.3.',
-            DeprecationWarning
-        )
-        return self.body.params
-    body_params = property(_get_body_params,
-                           doc="""
-    If the request Content-Type is 'application/x-www-form-urlencoded' or
-    multipart, this will be a dict of the params pulled from the entity
-    body; that is, it will be the portion of request.params that come
-    from the message body (sometimes called "POST params", although they
-    can be sent with various HTTP method verbs). This value is set between
-    the 'before_request_body' and 'before_handler' hooks (assuming that
-    process_request_body is True).
-
-    Deprecated in 3.2, will be removed for 3.3 in favor of
-    :attr:`request.body.params<cherrypy._cprequest.RequestBody.params>`.""")
-
 
 class ResponseBody(object):
 
@@ -900,7 +874,7 @@ class Response(object):
                 raise TypeError("Chunk %s is not of type 'bytes'." %
                                 repr(chunk))
             newbody.append(chunk)
-        newbody = ntob('').join(newbody)
+        newbody = b''.join(newbody)
 
         self.body = newbody
         return newbody
@@ -916,7 +890,7 @@ class Response(object):
 
         self.status = '%s %s' % (code, reason)
         self.output_status = ntob(str(code), 'ascii') + \
-            ntob(' ') + headers.encode(reason)
+            b' ' + headers.encode(reason)
 
         if self.stream:
             # The upshot: wsgiserver will chunk the response if
@@ -929,7 +903,7 @@ class Response(object):
             # and 304 (not modified) responses MUST NOT
             # include a message-body."
             dict.pop(headers, 'Content-Length', None)
-            self.body = ntob('')
+            self.body = b''
         else:
             # Responses which are not streamed should have a Content-Length,
             # but allow user code to set Content-Length if desired.
